==> webgui_7.10.23.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Map.pm <==
package WebGUI::i18n::German::Asset_Map;
use utf8;
our $I18N = {
  'add point label' => {
    'lastUpdated' => '1250972542',
    'message' => 'Position hinzufügen'
  },
  'assetName' => {
    'lastUpdated' => '1250971837',
    'message' => 'Landkarte'
  },
  'error add unauthorized' => {
    'lastUpdated' => '1250984055',
    'message' => 'Sie haben keine Berechtigung, um Positionen hinzuzufügen'
  },
  'error delete unauthorized' => {
    'lastUpdated' => '1250984023',
    'message' => 'Sie haben keine Berechtigung, um diese Position zu löschen'
  },
  'error edit unauthorized' => {
    'lastUpdated' => '1250984000',
    'message' => 'Sie haben keine Berechtigung, um diese Position zu bearbeiten'
  },
  'error set center unauthorized' => {
    'lastUpdated' => '1250983972',
    'message' => 'Sie haben keine Berechtigung um den Standardansichtsbereich festzulegen'
  },
  'groupIdAddPoint description' => {
    'lastUpdated' => '1250983937',
    'message' => 'Gruppe, die Positionen zur Karte hinzufügen darf.'
  },
  'groupIdAddPoint label' => {
    'lastUpdated' => '1250972470',
    'message' => 'Gruppe Position hinzufügen '
  },
  'mapApiKey description' => {
    'lastUpdated' => '1250971899',
    'message' => 'Der Google Maps API Schlüssel für diese Website'
  },
  'mapApiKey label' => {
    'lastUpdated' => '1250971919',
    'message' => 'Google Maps Schlüssel'
  },
  'mapApiKey link' => {
    'lastUpdated' => '1250971957',
    'message' => 'Holen Sie Ihren Google Maps API Schlüssel'
  },
  'mapHeight description' => {
    'lastUpdated' => '1250983905',
    'message' => 'Höhe der erzeugten Karte. Geben Sie die Einheit an in px=Pixel oder %=Prozent'
  },
  'mapHeight label' => {
    'lastUpdated' => '1250971972',
    'message' => 'Kartenhöhe'
  },
  'mapWidth description' => {
    'lastUpdated' => '1250983869',
    'message' => 'Breite der erzeugten Karte. Geben Sie die Einheit an in px=Pixel oder %=Prozent'
  },
  'mapWidth label' => {
    'lastUpdated' => '1250971984',
    'message' => 'Kartenbreite'
  },
  'message delete success' => {
    'lastUpdated' => '1250983808',
    'message' => 'Position gelöscht'
  },
  'message set center success' => {
    'lastUpdated' => '1250983775',
    'message' => 'Standardansichtsbereich erfolgreich definiert'
  },
  'message set point location' => {
    'lastUpdated' => '1250972486',
    'message' => 'Position aufgenommen'
  },
  'select a point' => {
    'lastUpdated' => '1257324685',
    'message' => 'Wählen Sie einen Punkt'
  },
  'set default viewing area label' => {
    'lastUpdated' => '1250983738',
    'message' => 'Einstellung Standardansichtsbereich'
  },
  'startLatitude description' => {
    'lastUpdated' => '1250972509',
    'message' => 'Geografische Breite der Startposition auf der Landkarte'
  },
  'startLatitude label' => {
    'lastUpdated' => '1250972225',
    'message' => 'Start geografische Breite (Latitude)'
  },
  'startLongitude description' => {
    'lastUpdated' => '1250972783',
    'message' => 'Geografische Länge zur Ausgangsposition auf der Karte'
  },
  'startLongitude label' => {
    'lastUpdated' => '1250972338',
    'message' => 'Start geografischer Länge (Longitude)'
  },
  'startZoom description' => {
    'lastUpdated' => '1250972523',
    'message' => 'Vergrößerungsfaktor des standard Startposition auf der Landkarte'
  },
  'startZoom label' => {
    'lastUpdated' => '1250972407',
    'message' => 'Startfaktor Vergrößerung'
  },
  'templateIdEditPoint description' => {
    'lastUpdated' => '1250983710',
    'message' => 'Vorlage um eine Kartenposition zu bearbeiten. Erscheint innerhalb der Karte.'
  },
  'templateIdEditPoint label' => {
    'lastUpdated' => '1250983640',
    'message' => 'Vorlage Bearbeitung Position'
  },
  'templateIdView description' => {
    'lastUpdated' => '1250983661',
    'message' => 'Vorlage für die Kartenansicht'
  },
  'templateIdView label' => {
    'lastUpdated' => '1250972607',
    'message' => 'Vorlage Kartenansicht'
  },
  'templateIdViewPoint description' => {
    'lastUpdated' => '1250972721',
    'message' => 'Vorlage zur Ansicht einer Kartenposition. Diese erscheint innerhalb der Karte.'
  },
  'templateIdViewPoint label' => {
    'lastUpdated' => '1250972589',
    'message' => 'Vorlage Ansicht Position'
  },
  'workflowIdPoint description' => {
    'lastUpdated' => '1250972666',
    'message' => 'Der Workflow, der abläuft, wenn eine Position hinzugefügt oder bearbeitet wird. '
  },
  'workflowIdPoint label' => {
    'lastUpdated' => '1250983513',
    'message' => 'Workflow zur Freigabe Kartenpositionen'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/German/Asset_Map.pm <==
package WebGUI::i18n::German::Asset_Map;
use utf8;
our $I18N = {
  'add point label' => {
    'lastUpdated' => '1250972542',
    'message' => 'Position hinzufügen'
  },
  'assetName' => {
    'lastUpdated' => '1250971837',
    'message' => 'Landkarte'
  },
  'button_addPoint' => {
    'lastUpdated' => '1305397288',
    'message' => 'Ein von einem Template gestalteten Knopf mit i18n-Bezeichnung zum Hinzufügen eines weiteren Knopfes.'
  },
  'button_setCenter' => {
    'lastUpdated' => '1305397403',
    'message' => 'Ein von einem Template gestalteten Knopf mit i18n-Bezeichnung zur Positionierung der Kartenmitte in die Ausgangsposition.'
  },
  'canAddPoint' => {
    'lastUpdated' => '1305397023',
    'message' => 'Ein boolischer Wert, der angibt, ob der aktuelle Benutzer eine Position hinzufügen kann.'
  },
  'canEdit' => {
    'lastUpdated' => '1305381313',
    'message' => 'Boolischer Wert. \'Wahr\', wenn der aktuelle Benutzer dieses Asset bearbeiten kann.'
  },
  'error add unauthorized' => {
    'lastUpdated' => '1250984055',
    'message' => 'Sie haben keine Berechtigung, um Positionen hinzuzufügen'
  },
  'error delete unauthorized' => {
    'lastUpdated' => '1250984023',
    'message' => 'Sie haben keine Berechtigung, um diese Position zu löschen'
  },
  'error edit unauthorized' => {
    'lastUpdated' => '1250984000',
    'message' => 'Sie haben keine Berechtigung, um diese Position zu bearbeiten'
  },
  'error set center unauthorized' => {
    'lastUpdated' => '1250983972',
    'message' => 'Sie haben keine Berechtigung um den Standardansichtsbereich festzulegen'
  },
  'groupIdAddPoint' => {
    'lastUpdated' => '1305418823',
    'message' => 'Die GUID der Gruppe, die Karten-Positionen hinzufügen kann'
  },
  'groupIdAddPoint description' => {
    'lastUpdated' => '1250983937',
    'message' => 'Gruppe, die Positionen zur Karte hinzufügen darf.'
  },
  'groupIdAddPoint label' => {
    'lastUpdated' => '1250972470',
    'message' => 'Gruppe Position hinzufügen '
  },
  'map asset template variables' => {
    'lastUpdated' => '1305418775',
    'message' => 'Karten-Asset Template Variabelen '
  },
  'mapApiKey' => {
    'lastUpdated' => '1305381354',
    'message' => 'Google Maps API Schlüssel'
  },
  'mapApiKey description' => {
    'lastUpdated' => '1250971899',
    'message' => 'Der Google Maps API Schlüssel für diese Website'
  },
  'mapApiKey label' => {
    'lastUpdated' => '1250971919',
    'message' => 'Google Maps Schlüssel'
  },
  'mapApiKey link' => {
    'lastUpdated' => '1250971957',
    'message' => 'Holen Sie Ihren Google Maps API Schlüssel'
  },
  'mapHeight' => {
    'lastUpdated' => '1305397056',
    'message' => 'Höhe der Kart, in Pixel'
  },
  'mapHeight description' => {
    'lastUpdated' => '1250983905',
    'message' => 'Höhe der erzeugten Karte. Geben Sie die Einheit an in px=Pixel oder %=Prozent'
  },
  'mapHeight label' => {
    'lastUpdated' => '1250971972',
    'message' => 'Kartenhöhe'
  },
  'mapPoints' => {
    'lastUpdated' => '1305381471',
    'message' => 'Eine Schleife mit Map-Positionen.
Verfügbare Vorlagenvariabelen werden in der Vorlagenbeschreibung aufgeführt.'
  },
  'mapWidth' => {
    'lastUpdated' => '1305397077',
    'message' => 'Breite der Karte, in Pixel'
  },
  'mapWidth description' => {
    'lastUpdated' => '1250983869',
    'message' => 'Breite der erzeugten Karte. Geben Sie die Einheit an in px=Pixel oder %=Prozent'
  },
  'mapWidth label' => {
    'lastUpdated' => '1250971984',
    'message' => 'Kartenbreite'
  },
  'message delete success' => {
    'lastUpdated' => '1250983808',
    'message' => 'Position gelöscht'
  },
  'message set center success' => {
    'lastUpdated' => '1250983775',
    'message' => 'Standardansichtsbereich erfolgreich definiert'
  },
  'message set point location' => {
    'lastUpdated' => '1250972486',
    'message' => 'Position aufgenommen'
  },
  'select a point' => {
    'lastUpdated' => '1257324685',
    'message' => 'Wählen Sie einen Punkt'
  },
  'selectPoint' => {
    'lastUpdated' => '1305397586',
    'message' => 'Von einem Template gestalteter Knopf zur Zentrierung der Karte um einen Punkt und zur Anzeige der Information dazu. '
  },
  'set default viewing area label' => {
    'lastUpdated' => '1250983738',
    'message' => 'Einstellung Standardansichtsbereich'
  },
  'startLatitude' => {
    'lastUpdated' => '1305381669',
    'message' => 'Anfangliche geografische Breite (Latitude) zur Kartenmitte'
  },
  'startLatitude description' => {
    'lastUpdated' => '1250972509',
    'message' => 'Geografische Breite der Startposition auf der Landkarte'
  },
  'startLatitude label' => {
    'lastUpdated' => '1250972225',
    'message' => 'Start geografische Breite (Latitude)'
  },
  'startLongitude' => {
    'lastUpdated' => '1305381653',
    'message' => 'Anfängliche geografische Länge der Kartenmitte'
  },
  'startLongitude description' => {
    'lastUpdated' => '1250972783',
    'message' => 'Geografische Länge zur Ausgangsposition auf der Karte'
  },
  'startLongitude label' => {
    'lastUpdated' => '1250972338',
    'message' => 'Start geografischer Länge (Longitude)'
  },
  'startZoom' => {
    'lastUpdated' => '1305381730',
    'message' => 'Anfänglicher Vergrößerungsfaktor der Karte'
  },
  'startZoom description' => {
    'lastUpdated' => '1250972523',
    'message' => 'Vergrößerungsfaktor des standard Startposition auf der Landkarte'
  },
  'startZoom label' => {
    'lastUpdated' => '1250972407',
    'message' => 'Startfaktor Vergrößerung'
  },
  'templateIdEditPoint' => {
    'lastUpdated' => '1305418683',
    'message' => 'Die GUID der Vorlage zur Änderung einer Position'
  },
  'templateIdEditPoint description' => {
    'lastUpdated' => '1250983710',
    'message' => 'Vorlage um eine Kartenposition zu bearbeiten. Erscheint innerhalb der Karte.'
  },
  'templateIdEditPoint label' => {
    'lastUpdated' => '1250983640',
    'message' => 'Vorlage Bearbeitung Position'
  },
  'templateIdView' => {
    'lastUpdated' => '1305418652',
    'message' => 'Die GUID der Vorlage zur Kartenansicht'
  },
  'templateIdView description' => {
    'lastUpdated' => '1250983661',
    'message' => 'Vorlage für die Kartenansicht'
  },
  'templateIdView label' => {
    'lastUpdated' => '1250972607',
    'message' => 'Vorlage Kartenansicht'
  },
  'templateIdViewPoint' => {
    'lastUpdated' => '1305418624',
    'message' => 'Die GUID der Vorlage für eine Position auf der Karte'
  },
  'templateIdViewPoint description' => {
    'lastUpdated' => '1250972721',
    'message' => 'Vorlage zur Ansicht einer Kartenposition. Diese erscheint innerhalb der Karte.'
  },
  'templateIdViewPoint label' => {
    'lastUpdated' => '1250972589',
    'message' => 'Vorlage Ansicht Position'
  },
  'view template' => {
    'lastUpdated' => '1305418558',
    'message' => 'Template Kartenansicht'
  },
  'workflowIdPoint' => {
    'lastUpdated' => '1305397658',
    'message' => 'Der GUID der Workflow zur Aktivierung einer Kartenposition'
  },
  'workflowIdPoint description' => {
    'lastUpdated' => '1250972666',
    'message' => 'Der Workflow, der abläuft, wenn eine Position hinzugefügt oder bearbeitet wird. '
  },
  'workflowIdPoint label' => {
    'lastUpdated' => '1250983513',
    'message' => 'Workflow zur Freigabe Kartenpositionen'
  }
}
;

1;
